@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class PrivatesConfig(AppConfig):
-    name = 'privates'
+    name = "privates"
